@@ -4,7 +4,7 @@ from explorer.actions import generate_report_action
 
 
 class QueryAdmin(admin.ModelAdmin):
-    list_display = ('title', 'description', 'created_by',)
+    list_display = ('title', 'description', 'created_by_user',)
     list_filter = ('title',)
     
     actions = [generate_report_action()]
