@@ -1,5 +1,5 @@
 from django.conf.urls import patterns, url
-from explorer.views import QueryView, CreateQueryView, PlayQueryView, DeleteQueryView, ListQueryView
+from explorer.views import QueryView, CreateQueryView, PlayQueryView, DeleteQueryView, ListQueryView, ListQueryLogView
 
 urlpatterns = patterns('',
     url(r'(?P<query_id>\d+)/$', QueryView.as_view(), name='query_detail'),
@@ -9,5 +9,6 @@ urlpatterns = patterns('',
     url(r'play/$', PlayQueryView.as_view(), name='explorer_playground'),
     url(r'csv$', 'explorer.views.csv_from_sql', name='generate_csv'),
     url(r'schema/$', 'explorer.views.schema', name='explorer_schema'),
+    url(r'logs/$', ListQueryLogView.as_view(), name='explorer_logs'),
     url(r'$', ListQueryView.as_view(), name='explorer_index'),
 )
\ No newline at end of file
