@@ -3,6 +3,7 @@ import csv
 import cStringIO
 import json
 import re
+import string
 from time import time
 from explorer import app_settings
 from django.db import connections, connection, models, transaction, DatabaseError
@@ -12,6 +13,7 @@ EXPLORER_PARAM_TOKEN = "$$"
 
 ## SQL Specific Things
 
+
 def passes_blacklist(sql):
     clean = functools.reduce(lambda sql, term: sql.upper().replace(term, ""), app_settings.EXPLORER_SQL_WHITELIST, sql)
     return not any(write_word in clean.upper() for write_word in app_settings.EXPLORER_SQL_BLACKLIST)
@@ -60,16 +62,22 @@ def transform_row(transforms, row):
     return row
 
 
-# returns schema information via django app inspection (sorted alphabetically by db table name):
-# [
-#     ("package.name -> ModelClass", "db_table_name",
-#         [
-#             ("db_column_name", "DjangoFieldType"),
-#             (...),
-#         ]
-#     )
-# ]
 def schema_info():
+    """
+    Construct schema information via introspection of the django models in the database.
+
+    :return: Schema information of the following form, sorted by db_table_name.
+        [
+            ("package.name -> ModelClass", "db_table_name",
+                [
+                    ("db_column_name", "DjangoFieldType"),
+                    (...),
+                ]
+            )
+        ]
+
+    """
+
     ret = []
     apps = [a for a in models.get_apps() if a.__package__ not in app_settings.EXPLORER_SCHEMA_EXCLUDE_APPS]
     for app in apps:
@@ -89,14 +97,13 @@ def schema_info():
                        [_format_field(f) for f in m2m.rel.through._meta.fields]
                     ) for m2m in model._meta.many_to_many]
 
-    return sorted(ret, key=lambda t: t[1])  # sort by table name
+    return sorted(ret, key=lambda t: t[1])
 
 
 def _format_field(field):
     return (field.get_attname_column()[1], field.get_internal_type())
 
 
-
 def param(name):
     return "%s%s%s" % (EXPLORER_PARAM_TOKEN, name, EXPLORER_PARAM_TOKEN)
 
@@ -122,10 +129,20 @@ def write_csv(headers, data):
     return csv_data.getvalue()
 
 
+def get_filename_for_title(title):
+    # build list of valid chars, build filename from title and replace spaces
+    valid_chars = '-_.() %s%s' % (string.ascii_letters, string.digits)
+    filename = ''.join(c for c in title if c in valid_chars)
+    filename = filename.replace(' ', '_')
+    return filename
+
+
 def build_download_response(query, request):
     data = csv_report(query, url_get_params(request))
     response = HttpResponse(data, content_type='text/csv')
-    response['Content-Disposition'] = 'attachment; filename=%s.csv' % query.title.replace(',', '')
+    response['Content-Disposition'] = 'attachment; filename="%s.csv"' % (
+        get_filename_for_title(query.title)
+    )
     response['Content-Length'] = len(data)
     return response
 
@@ -141,6 +158,8 @@ def csv_report(query, params=None):
 from django.contrib.admin.forms import AdminAuthenticationForm
 from django.contrib.auth.views import login
 from django.contrib.auth import REDIRECT_FIELD_NAME
+
+
 def safe_admin_login_prompt(request):
     defaults = {
         'template_name': 'admin/login.html',
