@@ -7,12 +7,16 @@ from django.views.generic.edit import CreateView, DeleteView
 from django.views.decorators.http import require_POST, require_GET
 from django.utils.decorators import method_decorator
 from django.core.urlresolvers import reverse_lazy
+from django.forms.models import model_to_dict
 
 from explorer.models import Query, QueryLog
 from explorer.app_settings import EXPLORER_PERMISSION_VIEW, EXPLORER_PERMISSION_CHANGE, EXPLORER_RECENT_QUERY_COUNT
 from explorer.forms import QueryForm
 from explorer.utils import url_get_rows, url_get_query_id, url_get_log_id, schema_info, url_get_params, safe_admin_login_prompt, build_download_response
 
+from collections import Counter
+import re
+
 
 def view_permission(f):
     def wrap(request, *args, **kwargs):
@@ -75,11 +79,54 @@ class ListQueryView(ExplorerContextMixin, ListView):
         return super(ListQueryView, self).dispatch(*args, **kwargs)
 
     def get_context_data(self, **kwargs):
-        recent_queries = Query.objects.all().order_by('-last_run_date')[:EXPLORER_RECENT_QUERY_COUNT]
         context = super(ListQueryView, self).get_context_data(**kwargs)
-        context['recent_queries'] = recent_queries
+        context['object_list'] = self._build_queries_and_headers()
+        context['recent_queries'] = Query.objects.all().order_by('-last_run_date')[:EXPLORER_RECENT_QUERY_COUNT]
         return context
 
+    def _build_queries_and_headers(self):
+        """
+        Build a list of query information and headers (pseudo-folders) for consumption by the template.
+
+        Strategy: Look for queries with titles of the form "something - else" (eg. with a ' - ' in the middle)
+                  and split on the ' - ', treating the left side as a "header" (or folder). Interleave the
+                  headers into the ListView's object_list as appropriate. Ignore headers that only have one
+                  child. The front end uses bootstrap's JS Collapse plugin, which necessitates generating CSS
+                  classes to map the header onto the child rows, hence the collapse_target variable.
+
+                  To make the return object homogeneous, convert the object_list models into dictionaries for
+                  interleaving with the header "objects". This necessitates special handling of 'created_at'
+                  and 'created_by_user' because model_to_dict doesn't include non-editable fields (created_at)
+                  and will give the int representation of the user instead of the string representation.
+
+        :return: A list of model dictionaries representing all the query objects, interleaved with header dictionaries.
+        """
+
+        dict_list = []
+        rendered_headers = []
+        pattern = re.compile('[\W_]+')
+
+        headers = Counter([q.title.split(' - ')[0] for q in self.object_list])
+
+        for q in self.object_list:
+            model_dict = model_to_dict(q)
+            header = q.title.split(' - ')[0]
+            collapse_target = pattern.sub('', header)
+
+            if headers[header] > 1 and header not in rendered_headers:
+                dict_list.append({'title': header,
+                                  'is_header': True,
+                                  'collapse_target': collapse_target,
+                                  'count': headers[header]})
+                rendered_headers.append(header)
+
+            model_dict.update({'is_in_category': headers[header] > 1,
+                               'collapse_target': collapse_target,
+                               'created_at': q.created_at,
+                               'created_by_user': q.created_by_user.__unicode__ if q.created_by_user else None})
+            dict_list.append(model_dict)
+        return dict_list
+
     model = Query
 
 
